<?php
/*
Plugin Name: WP评论区背景图助手
Plugin URI: https://dsdiss.com/
Description: 允许在后台设置背景图链接、显示宽度、#comment 锚点选择器、背景图位置、背景图透明度、背景图缩放比例等样式。
Version: 1.0
Author: 大神建站dsdiss.com
Author URI: https://dsdiss.com/
License: GPL2
*/

// 注册设置页面(dsdiss.com - 未经作者允许改版权死全家)
function background_image_plugin_settings_page() {
    add_options_page(
        'WP评论区背景图设置',
        'WP评论区背景图设置',
        'manage_options',
        'background-image-settings',
        'background_image_plugin_settings_page_content'
    );
}
add_action('admin_menu', 'background_image_plugin_settings_page');

function verify_captcha() {
    $correct_captcha = '4568';
    $is_verified = get_transient('background_image_captcha_verified');
    if ($is_verified) {
        return true;
    }
    if (isset($_POST['captcha']) && sanitize_text_field($_POST['captcha']) === $correct_captcha) {
        set_transient('background_image_captcha_verified', true, HOUR_IN_SECONDS);
        return true;
    }
    return false;
}

// 设置页面内容(dsdiss.com - 未经作者允许改版权死全家)
function background_image_plugin_settings_page_content() {
    $is_verified = verify_captcha();
    if ($is_verified) {
        if (isset($_POST['submit'])) {
            $background_image_url = sanitize_text_field($_POST['background_image_url']);
            $background_width = sanitize_text_field($_POST['background_width']);
            $comment_selector = sanitize_text_field($_POST['comment_selector']);
            $background_position = sanitize_text_field($_POST['background_position']);
            $background_opacity = sanitize_text_field($_POST['background_opacity']);
            $background_scale = sanitize_text_field($_POST['background_scale']);
            update_option('background_image_url', $background_image_url);
            update_option('background_width', $background_width);
            update_option('comment_selector', $comment_selector);
            update_option('background_position', $background_position);
            update_option('background_opacity', $background_opacity);
            update_option('background_scale', $background_scale);
            echo '<div class="updated"><p>设置已保存。</p></div>';
        }

        $background_image_url = get_option('background_image_url', 'https://e3f49eaa46b57.cdn.sohucs.com/2025/4/17/23/13/MTAwMTIyXzE3NDQ5MDI4MTU0OTc=.jpg');
        $background_width = get_option('background_width');
        $comment_selector = get_option('comment_selector', '#comment');
        $background_position = get_option('background_position', 'right');
        $background_opacity = get_option('background_opacity', '1');
        $background_scale = get_option('background_scale', '1');
        ?>
        <div class="wrap">
            <h1>背景图设置</h1>
            <form method="post" class="form-table">
                <table>
                    <tr>
                        <th><label for="background_image_url">背景图链接:</label></th>
                        <td><input type="text" name="background_image_url" id="background_image_url" value="<?php echo esc_attr($background_image_url); ?>" size="50"></td>
                    </tr>
                    <tr>
                        <th><label for="background_width">显示宽度:</label></th>
                        <td><input type="text" name="background_width" id="background_width" value="<?php echo esc_attr($background_width); ?>" size="50"></td>
                    </tr>
                    <tr>
                        <th><label for="comment_selector">评论选择器 (默认 #comment):</label></th>
                        <td><input type="text" name="comment_selector" id="comment_selector" value="<?php echo esc_attr($comment_selector); ?>" size="50"></td>
                    </tr>
                    <tr>
                        <th><label for="background_position">背景图位置:</label></th>
                        <td>
                            <select name="background_position" id="background_position">
                                <option value="left" <?php selected($background_position, 'left'); ?>>左</option>
                                <option value="center" <?php selected($background_position, 'center'); ?>>中</option>
                                <option value="right" <?php selected($background_position, 'right'); ?>>右</option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th><label for="background_opacity">背景图透明度 (0 - 1):</label></th>
                        <td><input type="number" step="0.1" min="0" max="1" name="background_opacity" id="background_opacity" value="<?php echo esc_attr($background_opacity); ?>" size="50"></td>
                    </tr>
                    <tr>
                        <th><label for="background_scale">背景图缩放比例:</label></th>
                        <td><input type="number" step="0.1" min="0" name="background_scale" id="background_scale" value="<?php echo esc_attr($background_scale); ?>" size="50"></td>
                    </tr>
                    <tr>
                        <td colspan="2"><input type="submit" name="submit" class="button button-primary" value="保存设置"></td>
                    </tr>
                </table>
            </form>
            <p style="text-align: center; font-size: 14px; color: #999;">本插件由<a href="https://dsdiss.com/" target="_blank">大神博客dsdiss.com</a>原创，务必保留所有权利，删除必究。</p>
        </div>
        <?php
    } else {
        ?>
        <div class="wrap">
            <h1>输入验证码</h1>
            <form method="post">
                <label for="captcha">验证码:</label><br>
                <input type="text" name="captcha" id="captcha" size="50"><br>
                <p style="font-size: 14px; color: #999;">关注微信公众号《一生闻》获取验证码</p>
                <input type="submit" name="submit_captcha" class="button button-primary" value="验证">
            </form>
        </div>
        <?php
    }
}

// 在页面中插入背景图样式(dsdiss.com - 未经作者允许改版权死全家)
function background_image_plugin_insert_styles($content) {
    $background_image_url = get_option('background_image_url', 'https://e3f49eaa46b57.cdn.sohucs.com/2025/4/17/23/13/MTAwMTIyXzE3NDQ5MDI4MTU0OTc=.jpg');
    $background_width = get_option('background_width');
    $comment_selector = get_option('comment_selector', '#comment');
    $background_position = get_option('background_position', 'center');
    $background_opacity = get_option('background_opacity', '0.5');
    $background_scale = get_option('background_scale', '1');

    if ($background_image_url) {
        $style = '<style>
            '. esc_html($comment_selector).' {
                background-image: url(' . esc_url($background_image_url) . ');
                background-repeat: no-repeat;
                background-position: '. esc_attr($background_position).' center;
                opacity: '. esc_attr($background_opacity).';
                width: ' . esc_attr($background_width). ';
                background-size: '. esc_attr($background_scale * 100). '% auto;
            }
        </style>';
        $content.= $style;
    }
    return $content;
}
add_filter('the_content', 'background_image_plugin_insert_styles');
    